@@ -143,6 +143,7 @@ def get_arg_name_list(
     """
     args_str = _get_args_str(
         code_str=py_module_str, func_name=func_name)
+    args_str = _remove_type_bracket_block_from_args_str(args_str=args_str)
     splitted_arg_name_list = args_str.split(',')
     arg_name_list = []
     for arg_name in splitted_arg_name_list:
@@ -808,6 +809,7 @@ def get_arg_default_val_info_dict(py_module_str, func_name):
     """
     args_str = _get_args_str(
         code_str=py_module_str, func_name=func_name)
+    args_str = _remove_type_bracket_block_from_args_str(args_str=args_str)
     if args_str == '':
         return {}
     splitted_arg_list = args_str.split(',')
@@ -826,6 +828,44 @@ def get_arg_default_val_info_dict(py_module_str, func_name):
     return default_val_info_dict
 
 
+def _remove_type_bracket_block_from_args_str(args_str: str):
+    """
+    Remove type annotation block bracket from arguments string.
+
+    Parameters
+    ----------
+    args_str : str
+        The target arguments string.
+        e.g., 'dict_val: Dict[str, int] == {}'
+
+    Returns
+    -------
+    result_str : str
+        The converted arguments string.
+        e.g., 'dict_val: Dict == {}'
+    """
+    if '[' not in args_str:
+        return args_str
+    bracket_count: int = 0
+    result_str: str = ''
+    is_type_block: bool = False
+    for char in args_str:
+        if bracket_count == 0 and char == ':':
+            is_type_block = True
+        if is_type_block and char == '[':
+            bracket_count += 1
+            continue
+        if is_type_block and char == ']':
+            bracket_count -= 1
+            continue
+        if bracket_count == 0 and (char == ',' or char == '='):
+            is_type_block = False
+        if bracket_count != 0:
+            continue
+        result_str += char
+    return result_str
+
+
 def _remove_type_str_from_arg_str(arg_str):
     """
     Remove the string of type information from the argument string.
@@ -840,6 +880,7 @@ def _remove_type_str_from_arg_str(arg_str):
     after_arg_str : str
         String after type information has been removed.
     """
+    arg_str = arg_str.replace(' = ', '=')
     is_in = ':' in arg_str
     if not is_in:
         return arg_str
