@@ -82,6 +82,13 @@ class SampleClass:
 
     def sample_func_6(self, cls, price, name, *args, **kwargs):
         pass
+
+def sample_func_7(price: int = 100, name: str = 'apple'):
+    pass
+
+
+def sample_func_8(dict_val: Optional[Dict[str, int]] = None):
+    pass
     """
 
     arg_name_list = helper.get_arg_name_list(
@@ -114,6 +121,14 @@ class SampleClass:
     assert arg_name_list == [
         'self', 'cls', 'price', 'name', '*args', '**kwargs']
 
+    arg_name_list = helper.get_arg_name_list(
+        py_module_str=py_module_str, func_name='sample_func_7')
+    assert arg_name_list == ['price', 'name']
+
+    arg_name_list = helper.get_arg_name_list(
+        py_module_str=py_module_str, func_name='sample_func_8')
+    assert arg_name_list == ['dict_val']
+
 
 def test_get_func_indent_num():
     py_module_str = """
@@ -726,12 +741,16 @@ def test__get_args_str():
         print(600)
 
 
-    def sample_func
+    def sample_func_7
     (
         price,
         name
     ):
         pass
+
+
+    def sample_func_8(dict_val: Optional[Dict[str, int]] = None):
+        pass
     """
     args_str = helper._get_args_str(
         code_str=code_str, func_name='sample_func_1')
@@ -758,7 +777,7 @@ def test__get_args_str():
     assert args_str == 'prince = 100, location_id = 200'
 
     args_str = helper._get_args_str(
-        code_str=code_str, func_name='sample_func')
+        code_str=code_str, func_name='sample_func_7')
     assert args_str == 'price, name'
 
 
@@ -775,6 +794,19 @@ def test_get_arg_default_val_info_dict():
     def sample_func_3(
             price: int, location_id: int=100) -> str:
         print(300)
+
+
+    def sample_func_4(
+            price: int = 100, name: str = 'apple') -> str:
+        print(300)
+
+
+    def sample_func_5(name: str = "apple") -> str:
+        print(300)
+
+
+    def sample_func_6(dict_value: Optional[Dict[str, int]] = None) -> str:
+        print(300)
     """
     default_val_info_dict = helper.get_arg_default_val_info_dict(
         py_module_str=py_module_str, func_name='sample_func_1')
@@ -797,6 +829,28 @@ def test_get_arg_default_val_info_dict():
     }
     assert default_val_info_dict == expected_dict
 
+    default_val_info_dict = helper.get_arg_default_val_info_dict(
+        py_module_str=py_module_str, func_name='sample_func_4')
+    expected_dict = {
+        'price': '100',
+        'name': "'apple'",
+    }
+    assert default_val_info_dict == expected_dict
+
+    default_val_info_dict = helper.get_arg_default_val_info_dict(
+        py_module_str=py_module_str, func_name='sample_func_5')
+    expected_dict = {
+        'name': '"apple"',
+    }
+    assert default_val_info_dict == expected_dict
+
+    default_val_info_dict = helper.get_arg_default_val_info_dict(
+        py_module_str=py_module_str, func_name='sample_func_6')
+    expected_dict = {
+        'dict_value': 'None',
+    }
+    assert default_val_info_dict == expected_dict
+
 
 def test__get_return_value_docstring():
     docstring = """
@@ -1684,6 +1738,10 @@ def test__remove_type_str_from_arg_str():
         arg_str=' price: int=100 ')
     assert after_arg_str == 'price=100'
 
+    after_arg_str = helper._remove_type_str_from_arg_str(
+        arg_str=' price: int = 100 ')
+    assert after_arg_str == 'price=100'
+
 
 def test__remove_nested_func_str():
     func_str = """
@@ -1746,3 +1804,27 @@ def test__type_anotation_comment_exists():
     result = helper._type_anotation_comment_exists(
         line_str='    # type: (int) -> str')
     assert result
+
+
+def test__remove_type_bracket_block_from_args_str():
+    args_str: str = (
+        'dict_val: Optional[Dict[str, int]] = None,'
+        ' tuple_val: Optional[Tuple[int, str, int]]=None'
+    )
+    result_str = helper._remove_type_bracket_block_from_args_str(
+        args_str=args_str)
+    expected_str = (
+        'dict_val: Optional = None, tuple_val: Optional=None'
+    )
+    assert result_str == expected_str
+
+    args_str: str = (
+        'list_val_1: List[int],'
+        ' list_val_2: Optional[List[int]] = [100, 200]'
+    )
+    result_str = helper._remove_type_bracket_block_from_args_str(
+        args_str=args_str)
+    expected_str = (
+        'list_val_1: List, list_val_2: Optional = [100, 200]'
+    )
+    assert result_str == expected_str
